@@ -13,8 +13,7 @@ import matplotlib.pyplot as plt
 import pyomo.environ as pe
 import pyomo.opt as po
 
-
-from ase.build import fcc111
+from ase.build import fcc111, fcc100, fcc110
 from ase.data import atomic_numbers, covalent_radii
 
 import pysmiles
@@ -32,11 +31,11 @@ class geom2graph:
     
     """
     
-    def __init__(self, surface_type = 'Pt', vasp = None, atoms = None, solver = 'glpk', distance_tune = 1.2, H_dist = 2.75, ddec6=None):
+    def __init__(self, surface_type = 'Pt', facet = 111, vasp = None, atoms = None, solver = 'glpk', distance_tune = 1.2, H_dist = 2.75, ddec6=None):
           
         self.surface_type = surface_type
         self.solver = solver
-        
+        self.facet = facet
         self.vasp = vasp    
         self.atoms = atoms
         self.ddec6 = ddec6
@@ -235,8 +234,16 @@ class geom2graph:
             n = set(self.find_nearest_neighbors([i])) - set(self.adsorbate_atoms)
             sum_cn += len(n)
         
-        bot_slab = fcc111(self.surface_type, (10,10,5), periodic = True)
+        if self.facet ==111:
+            bot_slab = fcc111(self.surface_type, (10,10,5), periodic = True)
+
+        elif self.facet==100:
+            bot_slab = fcc100(self.surface_type, (10,10,5), periodic = True)
+
+        elif self.facet == 110:
+            bot_slab = fcc100(self.surface_type, (10,10,5), periodic = True)
         cell_center = np.median(bot_slab.positions, axis = 0)
+
         
         active_site_poss = self.atoms[self.active_site].positions
         active_site_center = np.mean(self.atoms[self.active_site].positions, axis = 0)        
@@ -327,6 +334,7 @@ class geom2graph:
         
             self.graph.add_node(i)
             self.graph.nodes[i]['element'] = self.symbols[i]
+            self.graph.nodes[i]['position'] = self.positions[i,:]
             
         for i in self.edge_dict.keys():
             for j in self.edge_dict[i]:
@@ -446,7 +454,7 @@ class geom2graph:
                 nodes_ads[node] = node_dict[node]['valency']
 
         if not edges_ads and not edges_pts:
-            print('Solving ' + str(self.atoms[self.adsorbate_atoms].symbols))
+            print('Solving ' + str(self.atoms[self.adsorbate_atoms].symbols) + ' on' + str(self.surface_type))
             print('No adsorbate/slab edges; trivial solution returned')
             return None, None
         
@@ -583,7 +591,7 @@ if __name__=="__main__":
     # vasp = geom2graph(vasp = 'Examples/ase_to_graph/CONTCARpraneetalphahdown')
     # vasp = geom2graph(vasp = 'Examples/ase_to_graph/CONTCAR_CHCH_holhol')
     
-    ddec6 = gen_graph_ddec6('Examples/ddec6')
+    ddec6 = gen_graph_ddec6('Examples/ddec6/CH2CHCH3CH3')
     
     vasp = geom2graph(vasp = 'Examples/ase_to_graph/CONTCAR_Pt_CHOH_ontop', surface_type = 'Pt', ddec6=ddec6)
     
