@@ -25,7 +25,8 @@ from pysmiles import write_smiles
 import itertools
 
 class graph_enumerator:
-    def __init__(self, graphs, substrates = None):
+    
+    def __init__(self, graphs = [], rd_mol = [], substrates = None):
         
         for i in graphs:
             self.systems = [{'graph': i,
@@ -113,7 +114,6 @@ class graph_enumerator:
         entry['rdkit_mol'] = Chem.MolFromSmiles(smiles, sanitize=False)
                 
         
-
     def gen_subgraphs(self, smiles = False, regenerate = False):
         
         if smiles:
@@ -201,8 +201,6 @@ class graph_enumerator:
         
         return X, descriptors
 
-
-
     def get_graph_descriptors(self, graphs, max_graph_length=5):
         
         X,descriptors = list(), list()
