@@ -20,6 +20,8 @@ from itertools import compress
 
 from ase.data.colors import jmol_colors
 from ase.data import chemical_symbols
+from ase import formula
+
 
 
 def draw_surf_graph(graph, cutoff = 0.3, 
@@ -33,9 +35,10 @@ def draw_surf_graph(graph, cutoff = 0.3,
 
     plt.figure(figsize=(6,5))
    
-    metals = ['Ni', 'Ir','Pd','Pt']
-   
     colors = {i:j.reshape(1,-1) for i,j in zip(chemical_symbols, jmol_colors)}  
+
+    metals = [i for i in chemical_symbols if i not in formula.non_metals]
+    
     colors['M'] = [0.5, 0.5, 0.5]
 
     # for i in colors.keys():
